@@ -28,7 +28,7 @@ except ImportError:
 
 from adafruit_display_shapes.roundrect import RoundRect
 
-__version__ = "2.5.5"
+__version__ = "2.5.6"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Display_Shapes.git"
 
 
@@ -36,14 +36,14 @@ class Circle(RoundRect):
     # pylint: disable=too-few-public-methods, invalid-name
     """A circle.
 
-    :param x0: The x-position of the center.
-    :param y0: The y-position of the center.
-    :param r: The radius of the circle.
-    :param fill: The color to fill the circle. Can be a hex value for a color or
+    :param int x0: The x-position of the center.
+    :param int y0: The y-position of the center.
+    :param int r: The radius of the circle.
+    :param int|None fill: The color to fill the circle. Can be a hex value for a color or
                  ``None`` for transparent.
-    :param outline: The outline of the circle. Can be a hex value for a color or
+    :param int|None outline: The outline of the circle. Can be a hex value for a color or
                  ``None`` for no outline.
-    :param stroke: Used for the outline. Will not change the radius.
+    :param int stroke: Used for the outline. Will not change the radius.
 
     """
 
